@@ -1,5 +1,5 @@
 package Test::Spy::Object;
-$Test::Spy::Object::VERSION = '0.004';
+$Test::Spy::Object::VERSION = '0.005';
 use v5.10;
 use strict;
 use warnings;
@@ -32,7 +32,17 @@ sub isa
 	return !!1
 		if $self->{__base} && $self->{__base}->isa($name);
 
-	return !!0;
+	return $self->__imitates($name);
+}
+
+sub does
+{
+	my ($self, $name) = @_;
+
+	return !!1
+		if $self->{__base} && $self->{__base}->does($name);
+
+	return $self->__imitates($name);
 }
 
 sub DOES
@@ -42,7 +52,7 @@ sub DOES
 	return !!1
 		if $self->{__base} && $self->{__base}->DOES($name);
 
-	return !!0;
+	return $self->__imitates($name);
 }
 
 sub AUTOLOAD
@@ -77,7 +87,24 @@ sub AUTOLOAD
 	return undef;
 }
 
-sub _new
+sub __imitates
+{
+	my ($self, $name) = @_;
+
+	if ($self->{__spy}->has_imitates) {
+		my @imitates = $self->{__spy}->imitates;
+		@imitates = @{$imitates[0]}
+			if ref $imitates[0] eq 'ARRAY';
+
+		foreach my $type (@imitates) {
+			return !!1 if $type eq $name;
+		}
+	}
+
+	return !!0;
+}
+
+sub __new
 {
 	my ($class, %params) = @_;
 	my $self = \%params;
